DataCategories

Struct DataCategories 

pub struct DataCategories(/* private fields */);
An efficient container for data categories that avoids allocations.

It is a read only and has set like properties, allowing for fast comparisons.

Implementations

Source

impl DataCategories

pub fn new() -> Self

Creates new and empty DataCategories.

pub fn from_slice(slice: &[DataCategory]) -> Self

Creates a new DataCategories from the supplied slice of DataCategory values.

pub fn add(&self, category: DataCategory) -> Option<Self>

Adds a data category to Self.

Returns None if the category was already contained, otherwise creates a new Self with the category added.

pub fn contains(&self, category: &DataCategory) -> bool

Returns true iff the category is contained.

pub fn iter(&self) -> DataCategoryIterator

Returns an iterator over this DataCategories container.

pub fn len(&self) -> usize

Returns the number of categories in this container.

pub fn is_empty(&self) -> bool

Returns true iff this container contains no categories.