pub struct DimensionMap(/* private fields */);Expand description
A map of Dimension -> String
Implementations
Sourceimpl DimensionMap
impl DimensionMap
Sourcepub fn to_string(&self, quota: &Quota) -> Option<String>
pub fn to_string(&self, quota: &Quota) -> Option<String>
Converts the dimensions of this item scoping, for the supplied quota, into a string of the dimension name and hashed value. This looks like ‘:key1:hash1:key2:hash2’. This function assumes that the quota passed to it already matches this ItemScoping. If the