pub struct DataCategories(/* private fields */);Expand description
An efficient container for data categories that avoids allocations.
It is a read only and has set like properties, allowing for fast comparisons.
Implementations
Sourceimpl DataCategories
impl DataCategories
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates new and empty DataCategories.
Sourcepub fn from_slice(slice: &[DataCategory]) -> Self
pub fn from_slice(slice: &[DataCategory]) -> Self
Creates a new DataCategories from the supplied slice of DataCategory values.
Sourcepub fn add(&self, category: DataCategory) -> Option<Self>
pub fn add(&self, category: DataCategory) -> Option<Self>
Sourcepub fn contains(&self, category: &DataCategory) -> bool
pub fn contains(&self, category: &DataCategory) -> bool
Returns true iff the category is contained.
Sourcepub fn iter(&self) -> DataCategoryIterator ⓘ
pub fn iter(&self) -> DataCategoryIterator ⓘ
Returns an iterator over this DataCategories container.